# revertex

[![PyPI](https://img.shields.io/pypi/v/revertex?logo=pypi)](https://pypi.org/project/revertex/)
![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/legend-exp/revertex?logo=git)
[![GitHub Workflow Status](https://img.shields.io/github/checks-status/legend-exp/revertex/main?label=main%20branch&logo=github)](https://github.com/legend-exp/revertex/actions)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Codecov](https://img.shields.io/codecov/c/github/legend-exp/revertex?logo=codecov)](https://app.codecov.io/gh/legend-exp/revertex)
![GitHub issues](https://img.shields.io/github/issues/legend-exp/revertex?logo=github)
![GitHub pull requests](https://img.shields.io/github/issues-pr/legend-exp/revertex?logo=github)
![License](https://img.shields.io/github/license/legend-exp/revertex)
[![Read the Docs](https://img.shields.io/readthedocs/revertex?logo=readthedocs)](https://revertex.readthedocs.io)

_revertex_ provides functionality to generate event vertices (primarily
positions, but also kinematics) that can be read into _remage_ (see
[link](https://remage.readthedocs.io/en/latest/manual/generators.html#simulating-event-vertices-and-kinematics-from-external-files))

For more information see our [documentation](https://revertex.readthedocs.io)!
